from mceliece import mceliece6688128


def test_mceliece6688128():
    pk, sk = mceliece6688128.keypair()
    c, k1 = mceliece6688128.enc(pk)
    k2 = mceliece6688128.dec(c, sk)
    assert (k1 == k2)



from mceliece import mceliece8192128pcf


def test_mceliece8192128pcf():
    pk, sk = mceliece8192128pcf.keypair()
    c, k1 = mceliece8192128pcf.enc(pk)
    k2 = mceliece8192128pcf.dec(c, sk)
    assert (k1 == k2)



from mceliece import mceliece8192128pc


def test_mceliece8192128pc():
    pk, sk = mceliece8192128pc.keypair()
    c, k1 = mceliece8192128pc.enc(pk)
    k2 = mceliece8192128pc.dec(c, sk)
    assert (k1 == k2)



'''
Python wrapper around implementation of the Classic McEliece cryptosystem.

To access the Python functions provided by mceliece, import the library (for, e.g., mceliece6960119):

    from mceliece import mceliece6960119

To generate a key pair:

    pk,sk = mceliece6960119.keypair()

To generate a ciphertext c encapsulating a randomly generated session key k:

    c,k = mceliece6960119.enc(pk)

To recover a session key from a ciphertext:

    k = mceliece6960119.dec(c,sk)

As a larger example, the following test script creates a key pair, creates a ciphertext and session key, and then recovers the session key from the ciphertext:

    import mceliece
    kem = mceliece.mceliece6960119
    pk,sk = kem.keypair()
    c,k = kem.enc(pk)
    assert k == kem.dec(c,sk)
'''

from .kem import mceliece6960119
from .kem import mceliece6960119f
from .kem import mceliece6960119pc
from .kem import mceliece6960119pcf

from .kem import mceliece6688128
from .kem import mceliece6688128f
from .kem import mceliece6688128pc
from .kem import mceliece6688128pcf

from .kem import mceliece8192128
from .kem import mceliece8192128f
from .kem import mceliece8192128pc
from .kem import mceliece8192128pcf

from .kem import mceliece460896
from .kem import mceliece460896f
from .kem import mceliece460896pc
from .kem import mceliece460896pcf

from .kem import mceliece348864
from .kem import mceliece348864f
from .kem import mceliece348864pc
from .kem import mceliece348864pcf



from mceliece import mceliece460896pcf


def test_mceliece460896pcf():
    pk, sk = mceliece460896pcf.keypair()
    c, k1 = mceliece460896pcf.enc(pk)
    k2 = mceliece460896pcf.dec(c, sk)
    assert (k1 == k2)



from mceliece import mceliece8192128f


def test_mceliece8192128f():
    pk, sk = mceliece8192128f.keypair()
    c, k1 = mceliece8192128f.enc(pk)
    k2 = mceliece8192128f.dec(c, sk)
    assert (k1 == k2)
